"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useOnPressWithFocus = void 0;
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var react_native_1 = require("react-native");
/**
 * Sets focus on the focusRef after calling the userCallback for onPress, if that is an expected behavior on the platform
 * @param focusRef the ref used to set focus, generally the ref of the component that is being pressed
 * @param userCallback user-provided callback for onPress behavior
 * @returns Hook that sets focus, then calls the user callback
 */
function useOnPressWithFocus(focusRef, userCallback) {
    var onPressWithFocus = React.useCallback(function (args) {
        var _a;
        var platformSupportsFocus = ['windows', 'win32', 'macos'].includes(react_native_1.Platform.OS);
        var takesFocusOnClick = ['windows', 'win32'].includes(react_native_1.Platform.OS);
        if (platformSupportsFocus && takesFocusOnClick) {
            (_a = focusRef === null || focusRef === void 0 ? void 0 : focusRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
        userCallback === null || userCallback === void 0 ? void 0 : userCallback(args);
    }, [userCallback, focusRef]);
    return onPressWithFocus;
}
exports.useOnPressWithFocus = useOnPressWithFocus;
//# sourceMappingURL=useOnPressWithFocus.js.map