/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @flow strict-local
 * @format
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePressability = void 0;
var react_1 = require("react");
var Pressability_1 = require("./Pressability/Pressability");
function usePressability(config) {
    var pressabilityRef = (0, react_1.useRef)(null);
    if (pressabilityRef.current == null) {
        pressabilityRef.current = new Pressability_1.Pressability(config);
    }
    var pressability = pressabilityRef.current;
    // On the initial mount, this is a no-op. On updates, `pressability` will be
    // re-configured to use the new configuration.
    (0, react_1.useEffect)(function () {
        pressability.configure(config);
    }, [config, pressability]);
    // On unmount, reset pending state and timers inside `pressability`. This is
    // a separate effect because we do not want to reset when `config` changes.
    (0, react_1.useEffect)(function () {
        return function () {
            pressability.reset();
        };
    }, [pressability]);
    return pressability.getEventHandlers();
}
exports.usePressability = usePressability;
//# sourceMappingURL=usePressability.js.map