import { isAccessibilityActionEvent, isGestureResponderEvent, isKeyPressEvent } from '../events.types';
var createMockEvent = function (nativeEvent) {
    return {
        nativeEvent: nativeEvent,
        currentTarget: null,
        target: null,
        bubbles: false,
        cancelable: true,
        defaultPrevented: false,
        eventPhase: 0,
        isTrusted: false,
        preventDefault: function () {
            /* empty for test*/
        },
        isDefaultPrevented: function () {
            return false;
        },
        stopPropagation: function () {
            /* empty for test*/
        },
        isPropagationStopped: function () {
            return true;
        },
        persist: function () {
            /* empty for test*/
        },
        timeStamp: 0,
        type: '',
    };
};
var mockGestureEvent = createMockEvent({
    changedTouches: [],
    identifier: '',
    locationX: 0,
    locationY: 0,
    pageX: 0,
    pageY: 0,
    target: '',
    timestamp: 0,
    touches: [],
});
var mockKeyPressEvent = createMockEvent({
    key: 'enter',
});
var mockAccessibilityEvent = createMockEvent({
    actionName: 'longpress',
});
describe('InteractionEvent type guard tests', function () {
    it('has correct output from isGestureResponderEvent when input is type GestureResponderEvent', function () {
        expect(isGestureResponderEvent(mockGestureEvent)).toBeTruthy();
    });
    it('has correct output from isGestureResponderEvent when input is not type GestureResponderEvent', function () {
        expect(isGestureResponderEvent(mockAccessibilityEvent)).toBeFalsy();
    });
    it('has correct output from isKeyPressEvent when input is type KeyPressEvent', function () {
        expect(isKeyPressEvent(mockKeyPressEvent)).toBeTruthy();
    });
    it('has correct output from isKeyPressEvent when input is not type KeyPressEvent', function () {
        expect(isKeyPressEvent(mockGestureEvent)).toBeFalsy();
    });
    it('has correct output from isAccessibilityActionEvent when input is type AccessibilityActionEvent', function () {
        expect(isAccessibilityActionEvent(mockAccessibilityEvent)).toBeTruthy();
    });
    it('has correct output from isAccessibilityActionEvent when input is not type AccessibilityActionEvent', function () {
        expect(isAccessibilityActionEvent(mockGestureEvent)).toBeFalsy();
    });
});
//# sourceMappingURL=events.types.test.js.map