import * as React from 'react';
import { validateHookValueNotChanged } from '@fluentui-react-native/test-tools';
import { mount } from 'enzyme';
import { useControllableValue } from '../useControllableValue';
describe('useControllableValue', function () {
    it('respects controlled value', function () {
        var resultValue;
        var TestComponent = function (_a) {
            var value = _a.value, defaultValue = _a.defaultValue;
            resultValue = useControllableValue(value, defaultValue)[0];
            return React.createElement(React.Fragment, null);
        };
        var wrapper1 = mount(React.createElement(TestComponent, { value: true }));
        expect(resultValue).toBe(true);
        wrapper1.setProps({ value: false });
        expect(resultValue).toBe(false);
        var wrapper2 = mount(React.createElement(TestComponent, { value: false, defaultValue: true }));
        expect(resultValue).toBe(false);
        wrapper2.setProps({ value: true });
        expect(resultValue).toBe(true);
    });
    it('uses the default value if no controlled value is provided', function () {
        var resultValue;
        var TestComponent = function (_a) {
            var value = _a.value, defaultValue = _a.defaultValue;
            resultValue = useControllableValue(value, defaultValue)[0];
            return React.createElement(React.Fragment, null);
        };
        mount(React.createElement(TestComponent, { defaultValue: true }));
        expect(resultValue).toBe(true);
    });
    it('does not change value when the default value changes', function () {
        var resultValue;
        var TestComponent = function (_a) {
            var value = _a.value, defaultValue = _a.defaultValue;
            resultValue = useControllableValue(value, defaultValue)[0];
            return React.createElement(React.Fragment, null);
        };
        var wrapper = mount(React.createElement(TestComponent, { defaultValue: true }));
        expect(resultValue).toBe(true);
        wrapper.setProps({ defaultValue: false });
        expect(resultValue).toBe(true);
    });
    validateHookValueNotChanged('returns the same setter callback', function () {
        var _a = useControllableValue('hello', 'world'), setValue = _a[1];
        return [setValue];
    });
    validateHookValueNotChanged('returns same setter callback even if param values change', function () {
        var _a = useControllableValue('a', 'b', function () { return undefined; }), setValue = _a[1];
        return [setValue];
    }, function () {
        var _a = useControllableValue('c', 'd', function () { return undefined; }), setValue = _a[1];
        return [setValue];
    });
});
//# sourceMappingURL=useControllableValue.test.js.map