import { __assign } from "tslib";
import * as React from 'react';
import { Pressable } from 'react-native';
import { checkRenderConsistency, checkReRender } from '@fluentui-react-native/test-tools';
import * as renderer from 'react-test-renderer';
import { useKeyProps } from '../useKeyProps';
var dummyFunction = function () {
    console.log('dummy');
};
// Simple wrapper function to let us use `PressablePropsExtended` to fix type errors
var PressableWithDesktopProps = function (props) {
    return React.createElement(Pressable, __assign({}, props));
};
it('Pressable with useKeyProps', function () {
    var TestComponent = function () {
        var keyboardProps = useKeyProps(dummyFunction, ' ', 'Enter');
        return React.createElement(PressableWithDesktopProps, __assign({}, keyboardProps));
    };
    var tree = renderer.create(React.createElement(TestComponent, null)).toJSON();
    expect(tree).toMatchSnapshot();
});
it('useKeyProps called twice', function () {
    var TestComponent = function () {
        var keyboardProps1 = useKeyProps(dummyFunction, ' ', 'Enter');
        var keyboardProps2 = useKeyProps(dummyFunction, ' ', 'Enter');
        expect(keyboardProps1).toBe(keyboardProps2);
        return React.createElement(PressableWithDesktopProps, __assign({}, keyboardProps2));
    };
    var tree = renderer.create(React.createElement(TestComponent, null)).toJSON();
    expect(tree).toMatchSnapshot();
});
it('Pressable with useKeyProps simple rendering does not invalidate styling', function () {
    var TestComponent = function () {
        var keyboardProps = useKeyProps(dummyFunction, ' ', 'Enter');
        return React.createElement(PressableWithDesktopProps, __assign({}, keyboardProps));
    };
    checkRenderConsistency(function () { return React.createElement(TestComponent, null); }, 2);
});
it('Pressable with useKeyProps re-renders correctly', function () {
    var TestComponent = function () {
        var keyboardProps = useKeyProps(dummyFunction, ' ', 'Enter');
        return React.createElement(PressableWithDesktopProps, __assign({}, keyboardProps));
    };
    checkReRender(function () { return React.createElement(TestComponent, null); }, 2);
});
//# sourceMappingURL=useKeyProps.test.js.map