import { __assign } from "tslib";
import * as React from 'react';
import { usePressability } from './usePressability';
/**
 * hover specific state and callback helper
 */
function useHoverHelper(props) {
    var _a = React.useState({ hovered: false }), hoverState = _a[0], setHoverState = _a[1];
    var onHoverIn = React.useCallback(function (e) {
        setHoverState({ hovered: true });
        if (props.onHoverIn) {
            props.onHoverIn(e);
        }
    }, [setHoverState, props.onHoverIn]);
    var onHoverOut = React.useCallback(function (e) {
        setHoverState({ hovered: false });
        if (props.onHoverOut) {
            props.onHoverOut(e);
        }
    }, [setHoverState, props.onHoverOut]);
    return [{ onHoverIn: onHoverIn, onHoverOut: onHoverOut }, hoverState];
}
/**
 * focus specific state and callback helper
 */
function useFocusHelper(props) {
    var _a = React.useState({ focused: false }), focusState = _a[0], setFocusState = _a[1];
    var onFocus = React.useCallback(function (e) {
        setFocusState({ focused: true });
        if (props.onFocus) {
            props.onFocus(e);
        }
    }, [setFocusState, props.onFocus]);
    var onBlur = React.useCallback(function (e) {
        setFocusState({ focused: false });
        if (props.onBlur) {
            props.onBlur(e);
        }
    }, [setFocusState, props.onBlur]);
    return [{ onFocus: onFocus, onBlur: onBlur }, focusState];
}
/**
 * press specific state and callback helper
 */
function usePressHelper(props) {
    var _a = React.useState({ pressed: false }), pressState = _a[0], setPressState = _a[1];
    var onPressIn = React.useCallback(function (e) {
        setPressState({ pressed: true });
        if (props.onPressIn) {
            props.onPressIn(e);
        }
    }, [setPressState, props.onPressIn]);
    var onPressOut = React.useCallback(function (e) {
        setPressState({ pressed: false });
        if (props.onPressOut) {
            props.onPressOut(e);
        }
    }, [setPressState, props.onPressOut]);
    return [{ onPressIn: onPressIn, onPressOut: onPressOut }, pressState];
}
/**
 * A more focused version of useAsPressable, if only one state is needed.  Note that if two or more states are needed then useAsPressable is better
 * as each of these calls will create a new instance of the Pressability class.
 * @param props - input props for the component
 */
// eslint-disable-next-line @typescript-eslint/ban-types
export function useFocusState(props) {
    var _a = useFocusHelper(props), focusProps = _a[0], focusState = _a[1];
    return [__assign(__assign({}, props), usePressability(__assign(__assign({}, props), focusProps))), focusState];
}
/**
 * A more focused version of useAsPressable, if only one state is needed.  Note that if two or more states are needed then useAsPressable is better
 * as each of these calls will create a new instance of the Pressability class.
 * @param props - input props for the component
 */
// eslint-disable-next-line @typescript-eslint/ban-types
export function usePressState(props) {
    var _a = usePressHelper(props), pressProps = _a[0], pressState = _a[1];
    return [__assign(__assign({}, props), usePressability(__assign(__assign({}, props), pressProps))), pressState];
}
/**
 * A more focused version of useAsPressable, if only one state is needed.  Note that if two or more states are needed then useAsPressable is better
 * as each of these calls will create a new instance of the Pressability class.
 * @param props - input props for the component
 */
// eslint-disable-next-line @typescript-eslint/ban-types
export function useHoverState(props) {
    var _a = useHoverHelper(props), hoverProps = _a[0], hoverState = _a[1];
    return [__assign(__assign({}, props), usePressability(__assign(__assign({}, props), hoverProps))), hoverState];
}
/**
 * useAsPressable wraps the usePressability hook that will be available in RN 0.63 and beyond.  Once this library is on a recent enough
 * version of react-native this implementation can switch to using the official version.
 *
 * The useAsPressable hook adds a simple state change function for listening to hover, press, and focus events on the base pressability implementation
 * @param props - input props for the component, mixed in with pressable and pressability options
 */
// eslint-disable-next-line @typescript-eslint/ban-types
export function useAsPressable(props) {
    var _a = useHoverHelper(props), hoverProps = _a[0], hoverState = _a[1];
    var _b = useFocusHelper(props), focusProps = _b[0], focusState = _b[1];
    var _c = usePressHelper(props), pressProps = _c[0], pressState = _c[1];
    var pressabilityProps = usePressability(__assign(__assign(__assign(__assign({}, props), hoverProps), focusProps), pressProps));
    return {
        props: __assign(__assign({}, props), pressabilityProps),
        state: __assign(__assign(__assign({}, hoverState), focusState), pressState),
    };
}
//# sourceMappingURL=useAsPressable.js.map