import * as React from 'react';
import { useControllableValue } from './useControllableValue';
/* Re-usable hook for toggle components.
 * This hook configures the checked state, the callback to toggle the component
 * It handles the controlled/uncontrolled functionality of the toggle component.
 *
 * PROPS:  defaultChecked - Default checked state. Mutually exclusive to ‘checked’. This should come from userProps
 *         checked - Checked state. Mutually exclusive to 'defaultChecked'. This should come from userProps
 *         userCallback() - Callback provided by userProps when the checked (toggle) state changes
 * RETURNS:
 *         onChange() - Callback to toggle the component
 *         state.isChecked - Whether or not component is currently checked or selected
 */
export function useAsToggleWithEvent(defaultChecked, checked, userCallback) {
    var _a = useControllableValue(checked, defaultChecked), isChecked = _a[0], setChecked = _a[1];
    var onChange = React.useCallback(function (e) {
        userCallback && userCallback(e, !isChecked);
        setChecked(!isChecked);
    }, [isChecked, setChecked, userCallback]);
    return [isChecked, onChange];
}
//# sourceMappingURL=useAsToggleWithEvent.js.map