import type { KeyCallback, KeyPressEvent, KeyPressProps } from './useKeyProps.types';
declare function getKeyUpPropsWorker(userCallback: KeyCallback, ...keys: string[]): KeyPressProps;
declare function getKeyDownPropsWorker(userCallback: KeyCallback, ...keys: string[]): KeyPressProps;
/**
 * Re-usable hook for an onKeyUp event.
 * @param userCallback The function you want to be called once the key has been activated on key up
 * @param keys A string of the key you want to perform some action on. If undefined, always invokes userCallback
 * @returns KeyPressProps: An object containing the correct platform specific props to handle key press
 */
export declare const useKeyUpProps: typeof getKeyUpPropsWorker;
/**
 * Re-usable hook for an onKeyDown event.
 * @param userCallback The function you want to be called once the key has been activated on key down
 * @param keys A string of the key you want to perform some action on. If undefined, always invokes userCallback
 * @returns KeyPressProps: An object containing the correct platform specific props to  handle key press
 */
export declare const useKeyDownProps: typeof getKeyDownPropsWorker;
/** Exposes the behavior of useKeyProps for the current platform as a boolean */
export declare const preferKeyDownForKeyEvents: boolean;
/**
 * Re-usable hook for keyboard events. on macOS, this is onKeyDown, while on windows this is onKeyUp.
 * @param userCallback The function you want to be called once the key has been activated on key down
 * @param keys A string of the key you want to perform some action on. If undefined, always invokes userCallback
 * @returns KeyPressProps: An object containing the correct platform specific props to handle key press
 */
export declare const useKeyProps: typeof getKeyUpPropsWorker;
/**
 * Re-usable hook for an onKeyDown event.
 * @param userCallback The function you want to be called once the key has been activated on key up
 * @param keys A string of the key you want to perform some action on. If undefined, always invokes userCallback
 * @returns onKeyEvent() - Callback to determine if key was pressed, if so, call userCallback
 * @deprecated use the hook `useKeyProps` instead
 */
export declare function useKeyCallback(userCallback?: KeyCallback, ...keys: string[]): (e: KeyPressEvent) => void;
export {};
//# sourceMappingURL=useKeyProps.d.ts.map