import * as React from 'react';
import { Platform } from 'react-native';
/**
 * Sets focus on the focusRef after calling the userCallback for onPress, if that is an expected behavior on the platform
 * @param focusRef the ref used to set focus, generally the ref of the component that is being pressed
 * @param userCallback user-provided callback for onPress behavior
 * @returns Hook that sets focus, then calls the user callback
 */
export function useOnPressWithFocus(focusRef, userCallback) {
    var onPressWithFocus = React.useCallback(function (args) {
        var _a;
        var platformSupportsFocus = ['windows', 'win32', 'macos'].includes(Platform.OS);
        var takesFocusOnClick = ['windows', 'win32'].includes(Platform.OS);
        if (platformSupportsFocus && takesFocusOnClick) {
            (_a = focusRef === null || focusRef === void 0 ? void 0 : focusRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
        userCallback === null || userCallback === void 0 ? void 0 : userCallback(args);
    }, [userCallback, focusRef]);
    return onPressWithFocus;
}
//# sourceMappingURL=useOnPressWithFocus.js.map