import { __assign, __rest } from "tslib";
import * as React from 'react';
/**
 * hover specific state and callback helper
 */
export function useHoverHelper(props) {
    var _a = React.useState({ hovered: false }), hoverState = _a[0], setHoverState = _a[1];
    var onHoverIn = props.onHoverIn, onHoverOut = props.onHoverOut;
    var _onHoverIn = React.useCallback(function (e) {
        setHoverState({ hovered: true });
        onHoverIn === null || onHoverIn === void 0 ? void 0 : onHoverIn(e);
    }, [setHoverState, onHoverIn]);
    var _onHoverOut = React.useCallback(function (e) {
        setHoverState({ hovered: false });
        onHoverOut === null || onHoverOut === void 0 ? void 0 : onHoverOut(e);
    }, [setHoverState, onHoverOut]);
    return [{ onHoverIn: _onHoverIn, onHoverOut: _onHoverOut }, hoverState];
}
/**
 * focus specific state and callback helper
 */
export function useFocusHelper(props) {
    var _a = React.useState({ focused: false }), focusState = _a[0], setFocusState = _a[1];
    var onFocus = props.onFocus, onBlur = props.onBlur;
    var _onFocus = React.useCallback(function (e) {
        setFocusState({ focused: true });
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(e);
    }, [setFocusState, onFocus]);
    var _onBlur = React.useCallback(function (e) {
        setFocusState({ focused: false });
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
    }, [setFocusState, onBlur]);
    return [{ onFocus: _onFocus, onBlur: _onBlur }, focusState];
}
/**
 * press specific state and callback helper
 */
export function usePressHelper(props) {
    var _a = React.useState({ pressed: false }), pressState = _a[0], setPressState = _a[1];
    var onPressIn = props.onPressIn, onPressOut = props.onPressOut;
    var _onPressIn = React.useCallback(function (e) {
        setPressState({ pressed: true });
        onPressIn === null || onPressIn === void 0 ? void 0 : onPressIn(e);
    }, [setPressState, onPressIn]);
    var _onPressOut = React.useCallback(function (e) {
        setPressState({ pressed: false });
        onPressOut === null || onPressOut === void 0 ? void 0 : onPressOut(e);
    }, [setPressState, onPressOut]);
    return [{ onPressIn: _onPressIn, onPressOut: _onPressOut }, pressState];
}
/**
 * This routine hooks the props to pass to a Pressable component to obtain the current state of the Pressable as well as generating
 * state change updates when those props change. This allows a parent component to control the render of the whole component rather than having
 * to split the code between a child function or style function.
 *
 * @param props - props to pass to a Pressable component
 * @returns - modified props to pass into the Pressable as well as the current state with regards to hover, focus, and press
 */
export function usePressableState(props) {
    var onPressIn = props.onPressIn, onPressOut = props.onPressOut, onHoverIn = props.onHoverIn, onHoverOut = props.onHoverOut, onFocus = props.onFocus, onBlur = props.onBlur, rest = __rest(props, ["onPressIn", "onPressOut", "onHoverIn", "onHoverOut", "onFocus", "onBlur"]);
    var _a = useHoverHelper({ onHoverIn: onHoverIn, onHoverOut: onHoverOut }), hoverProps = _a[0], hoverState = _a[1];
    var _b = useFocusHelper({ onFocus: onFocus, onBlur: onBlur }), focusProps = _b[0], focusState = _b[1];
    var _c = usePressHelper({ onPressIn: onPressIn, onPressOut: onPressOut }), pressProps = _c[0], pressState = _c[1];
    return { props: __assign(__assign(__assign(__assign({}, hoverProps), focusProps), pressProps), rest), state: __assign(__assign(__assign({}, hoverState), focusState), pressState) };
}
//# sourceMappingURL=usePressableState.js.map