import * as React from 'react';
import { setAndForwardRef } from './setAndForwardRef';
/**
 * We need the win32 version of this hook to work around an lack of a UIManager.focus implementation.
 * On other platforms this hook is unnecessary.
 * @param forwardRef - The componentRef from your component's props where you're exposing a imperative focus method.
 * @returns The inner View-type you're rendering that you want to dispatch to & focus on.
 */
export function useViewCommandFocus(forwardedRef) {
    /**
     * Set up the forwarding ref to enable adding the focus method.
     */
    var focusRef = React.useRef();
    var _setNativeRef = setAndForwardRef({
        getForwardedRef: function () { return forwardedRef; },
        setLocalRef: function (localRef) {
            focusRef.current = localRef;
        },
    });
    return _setNativeRef;
}
//# sourceMappingURL=useViewCommandFocus.js.map